@@ -9,16 +9,17 @@ from probability.distributions.mixins.rv_mixins import RVS1dMixin, Moment1dMixin
 
 
 class RVContinuous1dMixin(
-    RVS1dMixin, Moment1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin, Var1dMixin, Interval1dMixin,
-    Support1dMixin, PDF1dMixin, CDFContinuous1dMixin, SFContinuous1dMixin, PPFContinuous1dMixin, ISFContinuous1dMixin,
-    PlottableMixin, object
+    RVS1dMixin, Moment1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin,
+    StD1dMixin, Var1dMixin, Interval1dMixin, Support1dMixin, PDF1dMixin,
+    CDFContinuous1dMixin, SFContinuous1dMixin, PPFContinuous1dMixin,
+    ISFContinuous1dMixin, PlottableMixin, object
 ):
 
     _distribution: rv_continuous
     _num_samples: int = 1000000
 
-    def plot(self, x: Iterable, kind: str = 'line', color: str = 'C0', ax: Axes = None,
-             **kwargs) -> Axes:
+    def plot(self, x: Iterable, kind: str = 'line', color: str = 'C0',
+             ax: Axes = None, **kwargs) -> Axes:
         """
         Plot the PDF of the distribution.
 
